==> qtjambi-location-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiLocation/QGeoCodingManager_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtLocation/qgeocodingmanager.h>
#include <QtCore/QVariant>
#include <QtLocation/qgeocodereply.h>
#include <QtPositioning/qgeoaddress.h>
#include <QtPositioning/qgeoshape.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtCore/qlocale.h>
#include <QtCore/QList>
#include <QtCore/qtimer.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qobject.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qregexp.h>
#include <QtCore/qthread.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QGeoCodingManager_0(){
    static int result = QMetaMethod::fromSignal(&QGeoCodingManager::error).methodIndex();
    return result;
}


int __signal_method_indexes_QGeoCodingManager_1(){
    static int result = QMetaMethod::fromSignal(&QGeoCodingManager::finished).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QGeoCodingManager::geocode(QGeoAddress,QGeoShape)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_geocode_1native_1cref_1QGeoAddress_1cref_1QGeoShape__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID address0,
 QtJambiNativeID bounds1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::geocode(QGeoAddress,QGeoShape)", __qt_this)
        const QGeoAddress& __qt_address0 = QtJambiAPI::valueReferenceFromNativeId<QGeoAddress>(address0);
        const QGeoShape& __qt_bounds1 = QtJambiAPI::valueReferenceFromNativeId<QGeoShape>(bounds1);
        QGeoCodeReply* __qt_return_value = __qt_this->geocode(__qt_address0, __qt_bounds1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::geocode(QString,int,int,QGeoShape)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_geocode_1native_1cref_1QString_1int_1int_1cref_1QGeoShape__JLjava_lang_String_2IIJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring searchString0,
 jint limit1,
 jint offset2,
 QtJambiNativeID bounds3)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::geocode(QString,int,int,QGeoShape)", __qt_this)
        QString  __qt_searchString0 = qtjambi_cast<QString >(__jni_env, searchString0);
        const QGeoShape& __qt_bounds3 = QtJambiAPI::valueReferenceFromNativeId<QGeoShape>(bounds3);
        QGeoCodeReply* __qt_return_value = __qt_this->geocode(__qt_searchString0, static_cast<int>(limit1), static_cast<int>(offset2), __qt_bounds3);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::locale()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_locale_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::locale()const", __qt_this)
        QLocale __qt_return_value = __qt_this->locale();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::managerName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_managerName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::managerName()const", __qt_this)
        QString __qt_return_value = __qt_this->managerName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::managerVersion()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_managerVersion_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::managerVersion()const", __qt_this)
        __java_return_value = __qt_this->managerVersion();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::reverseGeocode(QGeoCoordinate,QGeoShape)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_reverseGeocode_1native_1cref_1QGeoCoordinate_1cref_1QGeoShape__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID coordinate0,
 QtJambiNativeID bounds1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::reverseGeocode(QGeoCoordinate,QGeoShape)", __qt_this)
        const QGeoCoordinate& __qt_coordinate0 = QtJambiAPI::valueReferenceFromNativeId<QGeoCoordinate>(coordinate0);
        const QGeoShape& __qt_bounds1 = QtJambiAPI::valueReferenceFromNativeId<QGeoShape>(bounds1);
        QGeoCodeReply* __qt_return_value = __qt_this->reverseGeocode(__qt_coordinate0, __qt_bounds1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::setLocale(QLocale)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_setLocale_1native_1cref_1QLocale__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID locale0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::setLocale(QLocale)", __qt_this)
        const QLocale& __qt_locale0 = QtJambiAPI::valueReferenceFromNativeId<QLocale>(locale0);
        __qt_this->setLocale(__qt_locale0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QGeoCodeReply_Error(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QGeoCodeReply
bool javaToNativeConverter_QGeoCodeReply_ptr(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool javaToNativeConverter_QGeoCodeReply_ptr(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QGeoCodingManager
bool nativeToJavaConverter_QGeoCodeReply_Error(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QGeoCodeReply
bool nativeToJavaConverter_QGeoCodeReply_ptr(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);
bool nativeToJavaConverter_QGeoCodeReply_ptr_InvalidateAfterUse(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);

bool javaToNativeConverter_QGeoCodeReply_ptr(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    if(scope && !out){
        void** _out = new void*;
        scope->addDeletion(_out);
        out = _out;
    }
    if(!out)
        return false;
    *reinterpret_cast<QGeoCodeReply**>(out) = qtjambi_cast<QGeoCodeReply* >(env, in.l);
    return true;
}

bool nativeToJavaConverter_QGeoCodeReply_ptr(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QGeoCodeReply* const*>(in));
    return true;
}

bool nativeToJavaConverter_QGeoCodeReply_ptr_InvalidateAfterUse(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    if(!scope)
        return false;
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QGeoCodeReply* const*>(in));
    InvalidateAfterUse* __invalidate_out_after_use = new InvalidateAfterUse(env, out.l);
    scope->addDeletion(__invalidate_out_after_use);
    return true;
}


void initialize_meta_info_QGeoCodingManager(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QGeoCodingManager>("QGeoCodingManager", "io/qt/location/QGeoCodingManager");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QGeoCodingManager::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "error", "Lio/qt/core/QObject$Signal3Default1;", 3, __signal_method_indexes_QGeoCodingManager_0),
                SignalMetaInfo(/* 1 */ "finished", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QGeoCodingManager_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QGeoCodingManager_0()){ // error(QGeoCodeReply * reply, QGeoCodeReply::Error error, QString errorString)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // QGeoCodeReply*
                                method.parameterType(0),
                                "io/qt/location/QGeoCodeReply",
                                &nativeToJavaConverter_QGeoCodeReply_ptr,
                                &javaToNativeConverter_QGeoCodeReply_ptr);
                    infos << ParameterInfo(
                                // QGeoCodeReply::Error
                                method.parameterType(1),
                                "io/qt/location/QGeoCodeReply$Error",
                                &nativeToJavaConverter_QGeoCodeReply_Error,
                                &javaToNativeConverter_QGeoCodeReply_Error);
                    infos << ParameterInfo(QMetaType::QString);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QGeoCodingManager_1()){ // finished(QGeoCodeReply * reply)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // QGeoCodeReply*
                                method.parameterType(0),
                                "io/qt/location/QGeoCodeReply",
                                &nativeToJavaConverter_QGeoCodeReply_ptr_InvalidateAfterUse,
                                &javaToNativeConverter_QGeoCodeReply_ptr);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-location-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiLocation/QGeoCodingManager_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtLocation/qgeocodingmanager.h>
#include <QtCore/QVariant>
#include <QtLocation/qgeocodereply.h>
#include <QtPositioning/qgeoaddress.h>
#include <QtPositioning/qgeoshape.h>
#include <QtPositioning/qgeocoordinate.h>
#include <QtCore/qlocale.h>
#include <QtCore/qobject.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/QList>
#include <QtCore/qbytearray.h>
#include <QtCore/qtimer.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qproperty.h>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qthread.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qmetaobject.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

int __signal_method_indexes_QGeoCodingManager_0(){
    static int result = QMetaMethod::fromSignal(&QGeoCodingManager::errorOccurred).methodIndex();
    return result;
}


int __signal_method_indexes_QGeoCodingManager_1(){
    static int result = QMetaMethod::fromSignal(&QGeoCodingManager::finished).methodIndex();
    return result;
}


// emitting (writeConstructors)
// emitting  (functionsInTargetLang writeFinalFunction)
// QGeoCodingManager::geocode(QGeoAddress,QGeoShape)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_geocode_1native_1cref_1QGeoAddress_1cref_1QGeoShape__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID address0,
 QtJambiNativeID bounds1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::geocode(QGeoAddress,QGeoShape)", __qt_this)
        const QGeoAddress& __qt_address0 = QtJambiAPI::valueReferenceFromNativeId<QGeoAddress>(address0);
        const QGeoShape& __qt_bounds1 = QtJambiAPI::valueReferenceFromNativeId<QGeoShape>(bounds1);
        QGeoCodeReply* __qt_return_value = __qt_this->geocode(__qt_address0, __qt_bounds1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::geocode(QString,int,int,QGeoShape)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_geocode_1native_1cref_1QString_1int_1int_1cref_1QGeoShape__JLjava_lang_String_2IIJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring searchString0,
 jint limit1,
 jint offset2,
 QtJambiNativeID bounds3)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::geocode(QString,int,int,QGeoShape)", __qt_this)
        QString  __qt_searchString0 = qtjambi_cast<QString >(__jni_env, searchString0);
        const QGeoShape& __qt_bounds3 = QtJambiAPI::valueReferenceFromNativeId<QGeoShape>(bounds3);
        QGeoCodeReply* __qt_return_value = __qt_this->geocode(__qt_searchString0, static_cast<int>(limit1), static_cast<int>(offset2), __qt_bounds3);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::locale()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_locale_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::locale()const", __qt_this)
        QLocale __qt_return_value = __qt_this->locale();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::managerName()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_managerName_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::managerName()const", __qt_this)
        QString __qt_return_value = __qt_this->managerName();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::managerVersion()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_managerVersion_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::managerVersion()const", __qt_this)
        __java_return_value = __qt_this->managerVersion();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::reverseGeocode(QGeoCoordinate,QGeoShape)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_reverseGeocode_1native_1cref_1QGeoCoordinate_1cref_1QGeoShape__JJJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID coordinate0,
 QtJambiNativeID bounds1)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::reverseGeocode(QGeoCoordinate,QGeoShape)", __qt_this)
        const QGeoCoordinate& __qt_coordinate0 = QtJambiAPI::valueReferenceFromNativeId<QGeoCoordinate>(coordinate0);
        const QGeoShape& __qt_bounds1 = QtJambiAPI::valueReferenceFromNativeId<QGeoShape>(bounds1);
        QGeoCodeReply* __qt_return_value = __qt_this->reverseGeocode(__qt_coordinate0, __qt_bounds1);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QGeoCodingManager::setLocale(QLocale)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QGeoCodingManager_setLocale_1native_1cref_1QLocale__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID locale0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QGeoCodingManager *__qt_this = QtJambiAPI::objectFromNativeId<QGeoCodingManager>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QGeoCodingManager::setLocale(QLocale)", __qt_this)
        const QLocale& __qt_locale0 = QtJambiAPI::valueReferenceFromNativeId<QLocale>(locale0);
        __qt_this->setLocale(__qt_locale0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

bool javaToNativeConverter_QGeoCodeReply_Error(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QGeoCodeReply
bool javaToNativeConverter_QGeoCodeReply_ptr(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType);
bool javaToNativeConverter_QGeoCodeReply_ptr(JNIEnv*, QtJambiScope*, jvalue, void* &, jValueType); // declared in QGeoCodingManager
bool nativeToJavaConverter_QGeoCodeReply_Error(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool); // declared in QGeoCodeReply
bool nativeToJavaConverter_QGeoCodeReply_ptr(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);
bool nativeToJavaConverter_QGeoCodeReply_ptr_InvalidateAfterUse(JNIEnv*, QtJambiScope*, const void*, jvalue&, bool);

bool javaToNativeConverter_QGeoCodeReply_ptr(JNIEnv* env, QtJambiScope* scope, jvalue in, void* &out, jValueType) {
    Q_UNUSED(env)
    if(scope && !out){
        void** _out = new void*;
        scope->addDeletion(_out);
        out = _out;
    }
    if(!out)
        return false;
    *reinterpret_cast<QGeoCodeReply**>(out) = qtjambi_cast<QGeoCodeReply* >(env, in.l);
    return true;
}

bool nativeToJavaConverter_QGeoCodeReply_ptr(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    Q_UNUSED(scope)
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QGeoCodeReply* const*>(in));
    return true;
}

bool nativeToJavaConverter_QGeoCodeReply_ptr_InvalidateAfterUse(JNIEnv* env, QtJambiScope* scope, const void* in, jvalue& out, bool) {
    Q_UNUSED(env)
    if(!scope)
        return false;
    out.l = qtjambi_cast<jobject>(env, *reinterpret_cast<QGeoCodeReply* const*>(in));
    InvalidateAfterUse* __invalidate_out_after_use = new InvalidateAfterUse(env, out.l);
    scope->addDeletion(__invalidate_out_after_use);
    return true;
}


void initialize_meta_info_QGeoCodingManager(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QGeoCodingManager>("QGeoCodingManager", "io/qt/location/QGeoCodingManager");
// BEGIN: function table
// END: function table

    registerMetaObject(typeId, QGeoCodingManager::staticMetaObject, false,
            {
                SignalMetaInfo(/* 0 */ "errorOccurred", "Lio/qt/core/QObject$Signal3Default1;", 3, __signal_method_indexes_QGeoCodingManager_0),
                SignalMetaInfo(/* 1 */ "finished", "Lio/qt/core/QObject$Signal1;", 1, __signal_method_indexes_QGeoCodingManager_1)
            },
            [](const QMetaMethod& method, QList<ParameterInfo>& infos) {
                Q_UNUSED(infos)
                int methodIndex = method.methodIndex();
                if(methodIndex==__signal_method_indexes_QGeoCodingManager_0()){ // errorOccurred(QGeoCodeReply * reply, QGeoCodeReply::Error error, const QString & errorString)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // QGeoCodeReply*
                                method.parameterType(0),
                                "io/qt/location/QGeoCodeReply",
                                &nativeToJavaConverter_QGeoCodeReply_ptr,
                                &javaToNativeConverter_QGeoCodeReply_ptr);
                    infos << ParameterInfo(
                                // QGeoCodeReply::Error
                                method.parameterType(1),
                                "io/qt/location/QGeoCodeReply$Error",
                                &nativeToJavaConverter_QGeoCodeReply_Error,
                                &javaToNativeConverter_QGeoCodeReply_Error);
                    infos << ParameterInfo(QMetaType::QString);
                    return true;
                }
                if(methodIndex==__signal_method_indexes_QGeoCodingManager_1()){ // finished(QGeoCodeReply * reply)
                    infos << ParameterInfo(QMetaType::Void);
                    infos << ParameterInfo(
                                // QGeoCodeReply*
                                method.parameterType(0),
                                "io/qt/location/QGeoCodeReply",
                                &nativeToJavaConverter_QGeoCodeReply_ptr_InvalidateAfterUse,
                                &javaToNativeConverter_QGeoCodeReply_ptr);
                    return true;
                }
                return false;
            });
// END: signal table

// BEGIN: type registration
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
